==> shield34-1.0.345-345-py2.py3-none-any.whl: shield34_reporter/handler/__init__.py <==
import traceback

from shield34_reporter.auth.sdk_authentication import SdkAuthentication
from shield34_reporter.consts.shield34_properties import Shield34Properties
from shield34_reporter.container.run_report_container import RunReportContainer
from shield34_reporter.dynamic_locator.element_dynamic_locator import ElementDynamicLocator
from shield34_reporter.model.csv_rows.exception_caught_csv_row import ExceptionCaughtCsvRow
from shield34_reporter.model.csv_rows.helpers.exception_desc import ExceptionDesc
from shield34_reporter.model.csv_rows.html.PageHtmlCsvRow import PageHtml
from shield34_reporter.model.csv_rows.internalactions import RetryActionCsvRow, PerformActionCsvRow, \
    ExceptionRecoveredCsvRow
from shield34_reporter.model.csv_rows.step_failed_csv_row import StepFailedCsvRow
from shield34_reporter.model.csv_rows.test_action.action_ended_csv_row import ActionEndedCsvRow
from shield34_reporter.model.csv_rows.test_action.action_started_csv_row import ActionStartedCsvRow
from shield34_reporter.model.enums.exception_type import ExceptionType
from shield34_reporter.model.enums.placement import Placement
from shield34_reporter.utils.driver_utils import DriverUtils
from shield34_reporter.utils.screen_shots import ScreenShot


class HandlerAPI(object):
    return_value = None

    def do_orig_action(self):
        return False

    def action_pre_defenses(self):
        pass

    def action_validation(self):
        return True

    def on_successful_action(self):
        pass

    def handle_unsuccessful_action(self):
        return True

    def handle_exception(self, exception):
        return False

    def _set_return_value(self, value):
        self.return_value = value

    def _returned_value(self):
        return self.return_value


class SeleniumMethodHandler(HandlerAPI):
    value = None

    def __init__(self, action_name, action_csv_row):
        self.action_name = action_name
        self.action_csv_row = action_csv_row
        self.original_exception = None
        self.retry_count = 2
        self.timeout = 4
        self.polling = 0.2

    def _on_failed_action(self, exception):
        RunReportContainer.add_report_csv_row(PageHtml(DriverUtils.get_page_html()))
        if not Shield34Properties.screenshots_on_failure_disabled:
            ScreenShot.capture_screen_shoot(self.action_name.value, Placement.AFTER_FAILURE.value)
        if exception is not None:
            RunReportContainer.add_report_csv_row(StepFailedCsvRow(ExceptionDesc(exception).message))
            raise exception

    def _add_web_element_descriptor(self, web_element, by, locator):
        try:
            web_element_descriptor = ElementDynamicLocator.get_element_descriptor(web_element,
                                                                                  DriverUtils.get_current_driver(),
                                                                                  by, locator)
            if web_element_descriptor is not None:
                RunReportContainer.get_current_block_run_holder().webElementDescriptors.append(web_element_descriptor)
                RunReportContainer.get_current_block_run_holder().webElementDescriptorsMap[web_element.id] = web_element_descriptor
        except Exception as e:
            from shield34_reporter.model.csv_rows.debug_exception_log_csv_row import DebugExceptionLogCsvRow
            RunReportContainer.add_report_csv_row(
                DebugExceptionLogCsvRow("add web element descriptor failed.", e))

    def do_handle(self):
        if not SdkAuthentication.is_authorized():
            self.do_orig_action()
            return self._returned_value()
        current_block_run = RunReportContainer.get_current_block_run_holder()
        if current_block_run is None:
            self.do_orig_action()
            return self._returned_value()
        if current_block_run.action_already_started():
            self.do_orig_action()
            return self._returned_value()
        RunReportContainer.add_report_csv_row(ActionStartedCsvRow())
        RunReportContainer.add_report_csv_row(self.action_csv_row)
        try:
            success = False
            failed_action = False
            retry_counter = 0
            while not success and retry_counter < 2 and not failed_action:
                try:
                    if retry_counter > 0:
                        RunReportContainer.add_report_csv_row(RetryActionCsvRow(retry_counter, self.action_name))
                    retry_counter = retry_counter + 1
                    self.action_pre_defenses()

                    if not Shield34Properties.screenshots_disabled:
                        ScreenShot.capture_screen_shoot(self.action_name.value, Placement.BEFORE.value)
                    RunReportContainer.add_report_csv_row(PerformActionCsvRow(self.action_name.value, False))
                    if self.do_orig_action() and self.action_validation():
                        self.on_successful_action()
                        success = True
                    else:
                        failed_action = not self.handle_unsuccessful_action()
                except Exception as e:
                    RunReportContainer.add_report_csv_row(ExceptionCaughtCsvRow(exception=e, exception_type=ExceptionType.MAIN_ACTION))
                    if retry_counter == 1:
                        self.original_exception = e
                    if self.handle_exception(e):
                        RunReportContainer.add_report_csv_row(
                            ExceptionRecoveredCsvRow(True, e, ExceptionType.INTERNAL_ACTION))
                    else:
                        failed_action = True

            if not success:
                self._on_failed_action(self.original_exception)
            return self._returned_value()
        finally:
            RunReportContainer.add_report_csv_row(ActionEndedCsvRow())

==> shield34-1.0.349-349-py2.py3-none-any.whl: shield34_reporter/handler/__init__.py <==
import traceback

from shield34_reporter.auth.sdk_authentication import SdkAuthentication
from shield34_reporter.consts.shield34_properties import Shield34Properties
from shield34_reporter.container.run_report_container import RunReportContainer
from shield34_reporter.dynamic_locator.element_dynamic_locator import ElementDynamicLocator
from shield34_reporter.model.csv_rows.exception_caught_csv_row import ExceptionCaughtCsvRow
from shield34_reporter.model.csv_rows.helpers.exception_desc import ExceptionDesc
from shield34_reporter.model.csv_rows.html.PageHtmlCsvRow import PageHtml
from shield34_reporter.model.csv_rows.internalactions import RetryActionCsvRow, PerformActionCsvRow, \
    ExceptionRecoveredCsvRow
from shield34_reporter.model.csv_rows.step_failed_csv_row import StepFailedCsvRow
from shield34_reporter.model.csv_rows.test_action.action_ended_csv_row import ActionEndedCsvRow
from shield34_reporter.model.csv_rows.test_action.action_started_csv_row import ActionStartedCsvRow
from shield34_reporter.model.enums.exception_type import ExceptionType
from shield34_reporter.model.enums.placement import Placement
from shield34_reporter.utils.driver_utils import DriverUtils
from shield34_reporter.utils.screen_shots import ScreenShot


class HandlerAPI(object):
    return_value = None

    def do_orig_action(self):
        return False

    def action_pre_defenses(self):
        pass

    def action_validation(self):
        return True

    def on_successful_action(self):
        pass

    def handle_unsuccessful_action(self):
        return True

    def handle_exception(self, exception):
        return False

    def _set_return_value(self, value):
        self.return_value = value

    def _returned_value(self):
        return self.return_value


class SeleniumMethodHandler(HandlerAPI):
    value = None

    def __init__(self, action_name, action_csv_row):
        self.action_name = action_name
        self.action_csv_row = action_csv_row
        self.original_exception = None
        self.retry_count = 2
        self.timeout = 4
        self.polling = 0.2

    def _on_failed_action(self, exception):
        RunReportContainer.add_report_csv_row(PageHtml(DriverUtils.get_page_html()))
        if not Shield34Properties.screenshots_on_failure_disabled:
            ScreenShot.capture_screen_shoot(self.action_name.value, Placement.AFTER_FAILURE.value)
        if exception is not None:
            RunReportContainer.add_report_csv_row(StepFailedCsvRow(ExceptionDesc(exception).message))
            raise exception

    def _add_web_element_descriptor(self, driver, web_element, by, locator):
        try:
            web_element_descriptor = ElementDynamicLocator.get_element_descriptor(web_element,
                                                                                  driver,
                                                                                  by, locator)
            if web_element_descriptor is not None:
                RunReportContainer.get_current_block_run_holder().webElementDescriptors.append(web_element_descriptor)
                RunReportContainer.get_current_block_run_holder().webElementDescriptorsMap[web_element.id] = web_element_descriptor
        except Exception as e:
            from shield34_reporter.model.csv_rows.debug_exception_log_csv_row import DebugExceptionLogCsvRow
            RunReportContainer.add_report_csv_row(
                DebugExceptionLogCsvRow("add web element descriptor failed.", e))

    def do_handle(self):
        if not SdkAuthentication.is_authorized():
            self.do_orig_action()
            return self._returned_value()
        current_block_run = RunReportContainer.get_current_block_run_holder()
        if current_block_run is None:
            self.do_orig_action()
            return self._returned_value()
        if current_block_run.action_already_started():
            self.do_orig_action()
            return self._returned_value()
        RunReportContainer.add_report_csv_row(ActionStartedCsvRow())
        RunReportContainer.add_report_csv_row(self.action_csv_row)
        try:
            success = False
            failed_action = False
            retry_counter = 0
            while not success and retry_counter < 2 and not failed_action:
                try:
                    if retry_counter > 0:
                        RunReportContainer.add_report_csv_row(RetryActionCsvRow(retry_counter, self.action_name))
                    retry_counter = retry_counter + 1
                    self.action_pre_defenses()

                    if not Shield34Properties.screenshots_disabled:
                        ScreenShot.capture_screen_shoot(self.action_name.value, Placement.BEFORE.value)
                    RunReportContainer.add_report_csv_row(PerformActionCsvRow(self.action_name.value, False))
                    if self.do_orig_action() and self.action_validation():
                        self.on_successful_action()
                        success = True
                    else:
                        failed_action = not self.handle_unsuccessful_action()
                except Exception as e:
                    RunReportContainer.add_report_csv_row(ExceptionCaughtCsvRow(exception=e, exception_type=ExceptionType.MAIN_ACTION))
                    if retry_counter == 1:
                        self.original_exception = e
                    if self.handle_exception(e):
                        RunReportContainer.add_report_csv_row(
                            ExceptionRecoveredCsvRow(True, e, ExceptionType.INTERNAL_ACTION))
                    else:
                        failed_action = True

            if not success:
                self._on_failed_action(self.original_exception)
            return self._returned_value()
        finally:
            RunReportContainer.add_report_csv_row(ActionEndedCsvRow())
